<?php
App::uses('AppController', 'Controller');

/**
 * TinyMceImagePickerController
 *
 * Allows for the "selection"/"picking" of images from the admin CMS screen. It effectively
 * handles the loading of the screen that appears
 *
 * @property Event $Event
 * @property PaginatorComponent $Paginator
 */
class ImagePickerController extends AppController {

	/**
	 * just a permissions setup
	 */
	public $adminActions = array(
		'admin_select'
	);

	/**
	 * handles the selection of images inside a tinymce wysiwyg editor
	 *
	 * uses session variables that get set during the admin_edit of another model to
	 * determine which record and model we're talking about (i.e BlogPost and id 4). it
	 * then loads all the images for that record from the core ev image table, and
	 * populates a view variable with them.
	 */
	public function admin_select() {
		$this->layout = false;

		if (!$this->Session->check('EvTinyMceImage.model_id') || !$this->Session->check('EvTinyMceImage.model_reference')) {
			$this->set('images', array());
			return;
		}

		$model_id = $this->Session->read('EvTinyMceImage.model_id');
		$model_reference = $this->Session->read('EvTinyMceImage.model_reference');

		$ImageModel = ClassRegistry::init('EvCore.Image');

		$images = $ImageModel->find('all', [
			'conditions' => [
				'Image.model_id' => $model_id,
				'Image.model' => $model_reference,
			],
			'recursive' => 1
		]);

		$this->set('images', $images);

		return;
	}
}
